@@ -1,3 +1,5 @@
+import os
+
 from .api_request import APIRequest
 
 
@@ -18,7 +20,7 @@ class CreatableResource(APIRequest):
 
 class RetrievableResource(APIRequest):
     @classmethod
-    def retrieve(cls, scriptId, section=None, parameters=None, public=None, vast=None):
+    def retrieve(cls, scriptId, section=None, parameters=None, public=None, vast=None, endFormat=None):
         params = parameters.copy() if parameters else {}
         params.update({"scriptId": scriptId})
 
@@ -30,6 +32,9 @@ class RetrievableResource(APIRequest):
 
         if vast is not None:
             params.update({"vast": vast})
+        
+        if endFormat is not None:
+            params.update({"endFormat": endFormat})
 
         if cls.OBJECT_NAME == "script":
             return cls._get_request(path_param=f"{cls.resource_path}/{scriptId}")
@@ -74,3 +79,36 @@ class DownloadableResource(APIRequest):
             local_filenames.append(local_filename)
 
         return local_filenames
+
+
+class UploadableResource(APIRequest):
+    @classmethod
+    def upload(cls, file_path: str = "", tags: str = ""):
+        payload = open(file_path, "rb")
+        filename = os.path.basename(file_path)
+        headers = {"Content-Type": "audio/mpeg"}
+
+        request_params = {"filename": filename}
+
+        if tags:
+            request_params["tags"] = tags
+
+        # get presigned URL
+        url = cls._get_request(
+            path_param=f"{cls.audio_resource_path}/uploadurl",
+            request_params=request_params,
+        )
+
+        mediaId = url["mediaId"]
+        fileUploadUrl = url["fileUploadUrl"]
+
+        response = cls._put_request(url=fileUploadUrl, headers=headers, data=payload)
+
+        payload.close()
+
+        response = {
+            "message": f"Success. Use mediaId to retrieve this file",
+            "mediaId": mediaId,
+        }
+
+        return response
